@@ -5,13 +5,58 @@ from functools import (
     partial,
     update_wrapper as _update_wrapper,
     wraps as _wraps,
+    singledispatch,
 )
 from itertools import islice
 
-from typing import Any, Iterable, Iterator, Union, NewType
-from typing import Protocol, runtime_checkable
+from typing import (
+    Protocol,
+    runtime_checkable,
+    Tuple,
+    Callable,
+    Optional,
+    Generator,
+    Iterable,
+    Any,
+    Union,
+    NewType,
+    Iterator,
+)
 
-from functools import singledispatch, partial
+
+def iterate_skipping_errors(
+    g: Iterable,
+    error_callback: Optional[Callable[[BaseException], Any]] = None,
+    caught_exceptions: Tuple[BaseException] = (Exception,),
+) -> Generator:
+    """
+    Iterate over a generator, skipping errors and calling an error callback if provided.
+
+    :param g: The generator to iterate over
+    :param error_callback: A callback to call when an error is encountered.
+    :param caught_exceptions: The exceptions to catch and skip.
+    :return: A generator that yields the values of the original generator,
+    skipping errors.
+
+    >>> list(iterate_skipping_errors(map(lambda x: 1 / x, [1, 0, 2])))
+    [1.0, 0.5]
+    >>> list(iterate_skipping_errors(map(lambda x: 1 / x, [1, 0, 2]), print))
+    division by zero
+    [1.0, 0.5]
+
+    See https://github.com/i2mint/creek/issues/6 for more info.
+
+    """
+    iterator = iter(g)
+
+    while True:
+        try:
+            yield next(iterator)
+        except StopIteration:
+            break
+        except caught_exceptions as e:
+            if error_callback:
+                error_callback(e)
 
 
 def iterize(func, name=None):
@@ -200,8 +245,7 @@ def cursor_to_iterator(cursor: CursorFunc, sentinel=no_sentinel) -> Iterator:
 
 
 def iterable_to_cursor(iterable: Iterable) -> CursorFunc:
-    """Get a cursor function from an iterable.
-    """
+    """Get a cursor function from an iterable."""
     iterator = iterable_to_iterator(iterable)
     return iterator_to_cursor(iterator)
 
